<?php

declare(strict_types=1);

namespace Drupal\earkiv;

use Drupal\Component\Plugin\PluginBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\earkiv\Entity\Archive;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A base class to help developers implement their own E-Arkiv archiver plugins.
 *
 * @see \Drupal\earkiv\Annotation\Archiver
 * @see \Drupal\earkiv\ArchiverInterface
 */
abstract class ArchiverBase extends PluginBase implements ArchiverInterface {

  use StringTranslationTrait;

  /**
   * The plugin ID of this E-Arkiv archiver plugin.
   *
   * @var string
   */
  protected $pluginId;

  /**
   * The name of the provider that owns this E-Arkiv archiver plugin.
   *
   * @var string
   */
  public string $provider;


  /**
   * ArchiverBase constructor.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->provider = $this->pluginDefinition['provider'];
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getLabel(): string {
    return (string) $this->pluginDefinition['label'];
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): string {
    return (string) $this->pluginDefinition['description'];
  }

  /**
   * {@inheritdoc}
   */
  public function getConfiguration() {
    return $this->configuration;
  }

  /**
   * {@inheritdoc}
   */
  public function setConfiguration(array $configuration) {
    $this->configuration = $configuration;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'id' => $this->getPluginId(),
      'provider' => $this->pluginDefinition['provider'],
    ];
  }

  /**
   * Requirements for this plugin to function.
   *
   * @see hook_requirements()
   */
  public function requirements(string $phase): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function createArchive(Archive $entity): void {
  }

}
