<?php

declare(strict_types=1);

namespace Drupal\earkiv;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginFormInterface;
use Drupal\earkiv\Entity\Archive;
use Drush\Commands\DrushCommands;

/**
 * An interface for Archiver plugins.
 */
interface ArchiverInterface extends ConfigurableInterface, PluginInspectionInterface, PluginFormInterface, ContainerFactoryPluginInterface {

  /**
   * Archiver label.
   *
   * @return string
   *   The archiver plugin label.
   */
  public function getLabel(): string;

  /**
   * Archiver description.
   *
   * @return string
   *   The archiver plugin description.
   */
  public function getDescription(): string;

  /**
   * Create an archive.
   *
   * @param Archive $entity
   *   The entity representing the archive.
   * @return void
   */
  public function createArchive(Archive $entity): void;

  /**
   * Get the Drush commands class.
   *
   * @return NULL|DrushCommands
   *   The Drush commands class.
   */
  public function getDrushCommands(): NULL|DrushCommands;

}
