<?php

declare(strict_types=1);

namespace Drupal\earkiv\Form;

use Drupal\Core\Entity\ContentEntityConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Provides a form for deleting an 'earkiv_archive' entity.
 */
class ArchiveDeleteForm extends ContentEntityConfirmFormBase {

  /**
   * Returns the question to ask the user.
   *
   * @return string
   *   The form question. The page title will be set to this value.
   */
  public function getQuestion(): string {
    return (string) $this->t('Are you sure you want to delete the Archive %name?', array('%name' => $this->entity->label()));
  }

  /**
   * Returns the route to go to if the user cancels the action.
   */
  public function getCancelUrl(): Url {
    return new Url('entity.earkiv_archive.collection');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $entity = $this->getEntity();
    $entity->delete();
    $this->logger('earkiv')->notice('Deleted archive %label.', [
      '%label' => $this->entity->label(),
    ]);
    $form_state->setRedirect('entity.earkiv_archive.collection');
  }
}
