<?php

namespace Drupal\earkiv\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\earkiv\PluginOptionsTrait;

/**
 * Form controller for the 'earkiv_schedule' entity edit forms.
 */
class ScheduleForm extends ContentEntityForm {

  use PluginOptionsTrait;

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Name'),
      '#default_value' => $this->entity->label(),
      '#required' => TRUE,
    ];

    $form['rrule'] = [
      '#type' => 'textfield',
      '#title' => $this->t('RRule'),
      '#description' => $this->t('RRule for the schedule. Please visit <a href="https://freetools.textmagic.com/rrule-generator" target="_blank">RRULE generator</a> to generate a RRule.'),
      '#default_value' => $this->entity->get('rrule')->value,
      '#required' => TRUE,
    ];

    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Active'),
      '#description' => $this->t('Whether this schedule should be processed or not.'),
      '#default_value' => $this->entity->get('status')->value,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    parent::validateForm($form, $form_state);

    // TODO: Validate RRule.
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state): int {
    $status = parent::save($form, $form_state);

    $entity = $this->entity;
    if ($status == SAVED_UPDATED) {
      $this->messenger()
        ->addMessage($this->t('The Schedule %schedule has been updated.', ['%schedule' => $entity->label()]));
    } else {
      $this->messenger()
        ->addMessage($this->t('The Schedule %schedule has been created.', ['%schedule' => $entity->label()]));
    }

    $form_state->setRedirectUrl($this->entity->toUrl('collection'));
    return $status;
  }
}
